@@ -25,6 +25,7 @@
 #include <QTextStream>
 #include <QWidget>
 #include <QUrl>
+#include <kmessagebox.h>
 
 using namespace KgpgCore;
 
@@ -97,14 +98,10 @@ KGpgFirstAssistant::KGpgFirstAssistant(QWidget *parent)
 	gridLayout->addWidget(txtGpgVersion, 3, 1, 1, 1);
 
 	binURL = new KUrlRequester(page);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 108, 0)
 	binURL->setNameFilters({
 	    i18nc("search filter name for gpg binary", "GnuPG binary") + QLatin1String(" (gpg)"),
 	    i18n("All files") + QLatin1String(" (*)"),
 	});
-#else
-	binURL->setFilter(QLatin1String("gpg|") + i18nc("search filter name for gpg binary", "GnuPG binary") + QLatin1String("\n*|")+ i18n("All files"));
-#endif
 	QString gpgBin = QStandardPaths::findExecutable(QLatin1String("gpg2"));
 	if (gpgBin.isEmpty())
 		gpgBin = QStandardPaths::findExecutable(QLatin1String("gpg"));
@@ -241,7 +238,7 @@ KGpgFirstAssistant::findConfigPath(const QString &gpgBinary)
 		if (QFile(confPathOpt).exists()) {
 			confPath = confPathOpt;
 		} else {
-                        if (KMessageBox::questionYesNo(nullptr, i18n("<qt><b>The GnuPG configuration file was not found</b>. Should KGpg try to create a config file ?</qt>"), QString(), KGuiItem(i18n("Create Config")), KGuiItem(i18n("Do Not Create"))) == KMessageBox::Yes) {
+			if (KMessageBox::questionTwoActions(nullptr, i18n("<qt><b>The GnuPG configuration file was not found</b>. Should KGpg try to create a config file ?</qt>"), QString(), KGuiItem(i18n("Create Config")), KGuiItem(i18n("Do Not Create"))) == KMessageBox::PrimaryAction) {
 				QFile file(confPath);
 				if (file.open(QIODevice::WriteOnly)) {
 				    QTextStream stream(&file);
@@ -300,11 +297,7 @@ KGpgFirstAssistant::next()
 
 		if (!defaultID.isEmpty()) {
 			for (int i = 0; i < CBdefault->count(); i++) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-				if (CBdefault->itemData(i).toString().rightRef(defaultID.length()).compare(defaultID) == 0) {
-#else
 				if (QStringView(CBdefault->itemData(i).toString()).right(defaultID.length()).compare(defaultID) == 0) {
-#endif
 					CBdefault->setCurrentIndex(i);
 					break;
 				}
